@@ -16,7 +16,7 @@ module Fog
           data = []
           next_token = nil
           loop do
-            result = connection.describe_launch_configurations('NextToken' => next_token).body['DescribeLaunchConfigurationsResult']
+            result = service.describe_launch_configurations('NextToken' => next_token).body['DescribeLaunchConfigurationsResult']
             data += result['LaunchConfigurations']
             next_token = result['NextToken']
             break if next_token.nil?
@@ -25,7 +25,7 @@ module Fog
         end
 
         def get(identity)
-          data = connection.describe_launch_configurations('LaunchConfigurationNames' => identity).body['DescribeLaunchConfigurationsResult']['LaunchConfigurations'].first
+          data = service.describe_launch_configurations('LaunchConfigurationNames' => identity).body['DescribeLaunchConfigurationsResult']['LaunchConfigurations'].first
 	  new(data) unless data.nil?
         end
 
