@@ -11,7 +11,7 @@ module Fog
           data = []
           next_token = nil
           loop do
-            result = connection.describe_auto_scaling_instances('NextToken' => next_token).body['DescribeAutoScalingInstancesResult']
+            result = service.describe_auto_scaling_instances('NextToken' => next_token).body['DescribeAutoScalingInstancesResult']
             data += result['AutoScalingInstances']
             next_token = result['NextToken']
             break if next_token.nil?
@@ -20,7 +20,7 @@ module Fog
         end
 
         def get(identity)
-          data = connection.describe_auto_scaling_instances('InstanceIds' => identity).body['DescribeAutoScalingInstancesResult']['AutoScalingInstances'].first
+          data = service.describe_auto_scaling_instances('InstanceIds' => identity).body['DescribeAutoScalingInstancesResult']['AutoScalingInstances'].first
           new(data) unless data.nil?
         end
 
