@@ -9,12 +9,12 @@ module Fog
         model Fog::AWS::ElasticBeanstalk::Application
 
         def all(application_names=[])
-          data = connection.describe_applications(application_names).body['DescribeApplicationsResult']['Applications']
+          data = service.describe_applications(application_names).body['DescribeApplicationsResult']['Applications']
           load(data) # data is an array of attribute hashes
         end
 
         def get(application_name)
-          if data = connection.describe_applications([application_name]).body['DescribeApplicationsResult']['Applications'].first
+          if data = service.describe_applications([application_name]).body['DescribeApplicationsResult']['Applications'].first
             new(data)
           end
         end
