@@ -9,7 +9,7 @@ module Fog
         model Fog::AWS::ElasticBeanstalk::Event
 
         def all(options={})
-          data = connection.describe_events(options).body['DescribeEventsResult']['Events']
+          data = service.describe_events(options).body['DescribeEventsResult']['Events']
           load(data) # data is an array of attribute hashes
         end
 
