@@ -17,20 +17,20 @@ module Fog
 
         def destroy
           requires :id
-          connection.delete_cache_security_group(id)
+          service.delete_cache_security_group(id)
           true
         end
 
         def save
           requires :id
           requires :description
-          connection.create_cache_security_group(id, description)
+          service.create_cache_security_group(id, description)
         end
 
         def authorize_ec2_group(group_name, group_owner_id=owner_id)
           requires :id
           requires :owner_id if group_owner_id.nil?
-          data = connection.authorize_cache_security_group_ingress(
+          data = service.authorize_cache_security_group_ingress(
             id, group_name, group_owner_id
           )
           merge_attributes(data.body['CacheSecurityGroup'])
@@ -39,7 +39,7 @@ module Fog
         def revoke_ec2_group(group_name, group_owner_id=owner_id)
           requires :id
           requires :owner_id if group_owner_id.nil?
-          data = connection.revoke_cache_security_group_ingress(
+          data = service.revoke_cache_security_group_ingress(
             id, group_name, group_owner_id
           )
           merge_attributes(data.body['CacheSecurityGroup'])
