@@ -10,12 +10,12 @@ module Fog
         model Fog::AWS::RDS::ParameterGroup
 
         def all
-          data = connection.describe_db_parameter_groups.body['DescribeDBParameterGroupsResult']['DBParameterGroups']
+          data = service.describe_db_parameter_groups.body['DescribeDBParameterGroupsResult']['DBParameterGroups']
           load(data) # data is an array of attribute hashes
         end
 
         def get(identity)
-          data = connection.describe_db_parameter_groups(identity).body['DescribeDBParameterGroupsResult']['DBParameterGroups'].first
+          data = service.describe_db_parameter_groups(identity).body['DescribeDBParameterGroupsResult']['DBParameterGroups'].first
           new(data) # data is an attribute hash
         rescue Fog::AWS::RDS::NotFound
           nil
@@ -24,4 +24,4 @@ module Fog
       end
     end
   end
-end
\ No newline at end of file
+end
