@@ -10,12 +10,12 @@ module Fog
         model Fog::AWS::RDS::Server
 
         def all
-          data = connection.describe_db_instances.body['DescribeDBInstancesResult']['DBInstances']
+          data = service.describe_db_instances.body['DescribeDBInstancesResult']['DBInstances']
           load(data) # data is an array of attribute hashes
         end
 
         def get(identity)
-          data = connection.describe_db_instances(identity).body['DescribeDBInstancesResult']['DBInstances'].first
+          data = service.describe_db_instances(identity).body['DescribeDBInstancesResult']['DBInstances'].first
           new(data) # data is an attribute hash
         rescue Fog::AWS::RDS::NotFound
           nil
@@ -24,4 +24,4 @@ module Fog
       end
     end
   end
-end
\ No newline at end of file
+end
