@@ -7,11 +7,11 @@ module Fog
 
           def end_element(name)
             case name
-            when 'availabilityZone', 'requestId', 'snapshotId', 'status', 'volumeId'
+            when 'availabilityZone', 'requestId', 'snapshotId', 'status', 'volumeId', 'volumeType'
               @response[name] = value
             when 'createTime'
               @response[name] = Time.parse(value)
-            when 'size'
+            when 'size', 'iops'
               @response[name] = value.to_i
             end
           end
