@@ -12,20 +12,21 @@ module Fog
 
           def end_element(name)
             case name
-            when 'availabilityZone', 'instanceType', 'productDescription', 'reservedInstancesId', 'state'
+            when 'availabilityZone', 'instanceType', 'productDescription', 'reservedInstancesId', 'state', 'offeringType'
               @reserved_instance[name] = value
             when 'duration', 'instanceCount'
               @reserved_instance[name] = value.to_i
-            when 'fixedPrice', 'usagePrice'
+            when 'fixedPrice', 'amount', 'usagePrice'
               @reserved_instance[name] = value.to_f
             when 'item'
               @response['reservedInstancesSet'] << @reserved_instance
               @reserved_instance = {}
             when 'requestId'
               @response[name] = value
-            when 'start'
+            when 'start','end'
               @reserved_instance[name] = Time.parse(value)
             end
+
           end
 
         end
