@@ -33,6 +33,33 @@ module Fog
         end
 
       end
+
+      class Mock
+        def list_metrics(options={})
+          body = case options["NextToken"]
+                 when nil
+                   { "ListMetricsResult" => {
+                      "Metrics" => (0...500).map{ {} },
+                      "NextToken" => '1'
+                   }}
+                 when "1"
+                   { "ListMetricsResult" => {
+                      "Metrics" => (0...500).map{ {} },
+                      "NextToken" => '2'
+                   }}
+                 when "2"
+                   { "ListMetricsResult" => {
+                      "Metrics" => (0...1).map{ {} }
+                   }}
+                 end
+
+          Excon::Response.new.tap do |response|
+            response.body = body
+            response.status = 200
+          end
+        end
+      end
+
     end
   end
 end
