@@ -10,19 +10,14 @@ module Fog
           raise ArgumentError.new("Filters must be a hash, but is a #{filters.class}.") unless filters.is_a?(Hash)
           next_token = filters.delete('nextToken') || filters.delete('NextToken')
           max_results = filters.delete('maxResults') || filters.delete('MaxResults')
-          volume_ids = filters.delete('VolumeId')
 
-          params = Fog::AWS.indexed_filters(filters)
+          params = Fog::AWS.indexed_request_param('VolumeId', filters.delete('VolumeId'))
+
+          params.merge!(Fog::AWS.indexed_filters(filters))
 
           params['NextToken'] = next_token if next_token
           params['MaxResults'] = max_results if max_results
 
-          Array(volume_ids).inject(1) do |idx, vid|
-            params["VolumeId.#{idx}"] = vid
-            idx += 1
-          end
-
-          pp params
           request({
             'Action'    => 'DescribeVolumeStatus',
             :idempotent => true,
