@@ -31,7 +31,7 @@ module Fog
           }.merge(options)
 
           request(
-            :body       => MultiJson.encode(body),
+            :body       => Fog::JSON.encode(body),
             :headers    => {'x-amz-target' => 'DynamoDB_20111205.GetItem'},
             :idempotent => true
           )
