@@ -35,10 +35,18 @@ module Fog
       end
 
       class Mock
-        def reboot_cache_cluster
-          Fog::Mock.not_implemented
+        def reboot_cache_cluster(id, nodes_to_reboot)
+          response        = Excon::Response.new
+          response.body   = {
+            'CacheCluster' => self.data[:clusters][id].merge({
+              'CacheClusterStatus' => 'rebooting cache cluster nodes'
+            }),
+            'ResponseMetadata'  => { 'RequestId' => Fog::AWS::Mock.request_id }
+          }
+          response
         end
       end
+
     end
   end
 end
