@@ -6,7 +6,7 @@ module Fog
         require 'fog/aws/parsers/iam/basic'
 
         # Add or update a policy for a group
-        # 
+        #
         # ==== Parameters
         # * group_name<~String>: name of the group
         # * policy_name<~String>: name of policy document
@@ -25,12 +25,28 @@ module Fog
             'Action'          => 'PutGroupPolicy',
             'GroupName'       => group_name,
             'PolicyName'      => policy_name,
-            'PolicyDocument'  => MultiJson.encode(policy_document),
+            'PolicyDocument'  => Fog::JSON.encode(policy_document),
             :parser           => Fog::Parsers::AWS::IAM::Basic.new
           )
         end
 
       end
+      class Mock
+        #FIXME: You can't actually use the credentials for anything elsewhere in Fog
+        #FIXME: Doesn't do any validation on the policy
+        def put_group_policy(group_name, policy_name, policy_document)
+          if data[:groups].has_key? group_name
+            data[:groups][group_name][:policies][policy_name] = policy_document
+
+            Excon::Response.new.tap do |response|
+              response.body = { 'RequestId' => Fog::AWS::Mock.request_id }
+              response.status = 200
+            end
+          else
+            raise Fog::AWS::IAM::NotFound.new("The group with name #{group_name} cannot be found.")
+          end
+        end
+      end
     end
   end
 end
