@@ -5,19 +5,17 @@ module Fog
 
         # Change bucket policy for an S3 bucket
         #
-        # ==== Parameters
-        # * bucket_name<~String> - name of bucket to modify
-        # * policy<~Hash> - policy document 
+        # @param bucket_name [String] name of bucket to modify
+        # @param policy [Hash] policy document
         #
-        # ==== See Also
-        # http://docs.amazonwebservices.com/AmazonS3/latest/API/RESTBucketPUTpolicy.html 
+        # @see http://docs.amazonwebservices.com/AmazonS3/latest/API/RESTBucketPUTpolicy.html
 
         def put_bucket_policy(bucket_name, policy)
           request({
-            :body     => MultiJson.encode(policy),
+            :body     => Fog::JSON.encode(policy),
             :expects  => 204,
             :headers  => {},
-            :host     => "#{bucket_name}.#{@host}",
+            :bucket_name => bucket_name,
             :method   => 'PUT',
             :query    => {'policy' => nil}
           })
