@@ -1,10 +1,11 @@
-require(File.expand_path(File.join(File.dirname(__FILE__), 'core')))
+require 'fog/core'
 
 module Fog
   module Bluebox
 
     extend Fog::Provider
 
+    service(:blb,     'bluebox/blb',      'BLB')
     service(:compute, 'bluebox/compute',  'Compute')
     service(:dns,     'bluebox/dns',      'DNS')
 
