@@ -10,12 +10,12 @@ module Fog
         model Fog::Compute::Bluebox::Location
 
         def all
-          data = connection.get_locations.body
+          data = service.get_locations.body
           load(data)
         end
 
         def get(location_id)
-          response = connection.get_location(location_id)
+          response = service.get_location(location_id)
           new(response.body)
         rescue Fog::Compute::Bluebox::NotFound
           nil
