@@ -10,12 +10,12 @@ module Fog
         model Fog::DNS::Bluebox::Zone
 
         def all
-          data = connection.get_zones.body['zones']
+          data = service.get_zones.body['zones']
           load(data)
         end
 
         def get(zone_id)
-          data = connection.get_zone(zone_id).body
+          data = service.get_zone(zone_id).body
           new(data)
         rescue Fog::Service::NotFound
           nil
