@@ -10,20 +10,20 @@ module Fog
         model Fog::Compute::Brightbox::CloudIp
 
         def all
-          data = connection.list_cloud_ips
+          data = service.list_cloud_ips
           load(data)
         end
 
         def get(identifier)
           return nil if identifier.nil? || identifier == ""
-          data = connection.get_cloud_ip(identifier)
+          data = service.get_cloud_ip(identifier)
           new(data)
         rescue Excon::Errors::NotFound
           nil
         end
 
         def allocate
-          data = connection.create_cloud_ip
+          data = service.create_cloud_ip
           new(data)
         end
 
@@ -31,4 +31,4 @@ module Fog
 
     end
   end
-end
\ No newline at end of file
+end
