@@ -10,13 +10,13 @@ module Fog
         model Fog::Compute::Brightbox::Zone
 
         def all
-          data = connection.list_zones
+          data = service.list_zones
           load(data)
         end
 
         def get(identifier)
           return nil if identifier.nil? || identifier == ""
-          data = connection.get_zone(identifier)
+          data = service.get_zone(identifier)
           new(data)
         rescue Excon::Errors::NotFound
           nil
@@ -26,4 +26,4 @@ module Fog
 
     end
   end
-end
\ No newline at end of file
+end
