@@ -15,6 +15,15 @@ module Fog
         end
 
       end
+
+      class Mock
+        # TODO: add id, category_id filters and paging params
+        def list_os_types(options={})
+          os_types = self.data[:os_types]
+          { "listostypesresponse" => { "count"=> os_types.count, "ostype"=> os_types.values } }
+        end
+
+      end
     end
   end
 end
