@@ -1,3 +1,5 @@
+require 'time'
+
 module Fog
   class Time < ::Time
 
@@ -22,5 +24,9 @@ module Fog
       self.utc.strftime("#{DAYS[self.utc.wday]}, %d #{MONTHS[self.utc.month - 1]} %Y %H:%M:%S +0000")
     end
 
+    def to_iso8601_basic
+      self.utc.strftime('%Y%m%dT%H%M%SZ')
+    end
+
   end
 end
