@@ -1,6 +1,5 @@
 module Fog
-
-  def self.wait_for(timeout=Fog.timeout, interval=1, &block)
+  def self.wait_for(timeout=Fog.timeout, interval=Fog.interval, &block)
     duration = 0
     start = Time.now
     until yield || duration > timeout
@@ -8,10 +7,9 @@ module Fog
       duration = Time.now - start
     end
     if duration > timeout
-      false
+      raise Errors::TimeoutError.new("The specified wait_for timeout (#{timeout} seconds) was exceeded")
     else
       { :duration => duration }
     end
   end
-  
 end
