@@ -1,6 +1,6 @@
 require 'nokogiri'
 
-require(File.expand_path(File.join(File.dirname(__FILE__), 'core')))
+require 'fog/core'
 require 'fog/core/parser'
 
 module Fog
