@@ -10,12 +10,12 @@ module Fog
         model Fog::Compute::IBM::Address
 
         def all
-          load(connection.list_addresses.body['addresses'])
+          load(service.list_addresses.body['addresses'])
         end
 
         def get(address_id)
           begin
-            address = connection.list_addresses.body
+            address = service.list_addresses.body
             new(address['addresses'].find{|address| address['id'] == address_id.to_s })
           rescue Fog::Compute::IBM::NotFound
             nil
