@@ -10,12 +10,12 @@ module Fog
         model Fog::Storage::IBM::Volume
 
         def all
-          load(connection.list_volumes.body['volumes'])
+          load(service.list_volumes.body['volumes'])
         end
 
         def get(volume_id)
           begin
-            new(connection.get_volume(volume_id).body)
+            new(service.get_volume(volume_id).body)
           rescue Fog::Storage::IBM::NotFound
             nil
           end
