@@ -27,9 +27,9 @@ module Fog
 
         private
         def disks(linode_id, id=nil)
-          connection.linode_disk_list(linode_id, id).body['DATA'].map { |disk| map_disk disk }
+          service.linode_disk_list(linode_id, id).body['DATA'].map { |disk| map_disk disk }
         end
-        
+
         def map_disk(disk)
           disk = disk.each_with_object({}) { |(k, v), h| h[k.downcase.to_sym] = v  }
           disk.merge! :id => disk[:diskid], :name => disk[:label], :server_id => disk[:linodeid]
