@@ -19,9 +19,9 @@ module Fog
 
         private
         def flavors(id=nil)
-          connection.avail_linodeplans(id).body['DATA'].map { |flavor| map_flavor flavor }
+          service.avail_linodeplans(id).body['DATA'].map { |flavor| map_flavor flavor }
         end
-        
+
         def map_flavor(flavor)
           flavor = flavor.each_with_object({}) { |(k, v), h| h[k.downcase.to_sym] = v  }
           flavor.merge! :id => flavor[:planid], :name => flavor[:label]
