@@ -19,9 +19,9 @@ module Fog
 
         private
         def kernels(id=nil)
-          connection.avail_kernels(id).body['DATA'].map { |kernel| map_kernel kernel }
+          service.avail_kernels(id).body['DATA'].map { |kernel| map_kernel kernel }
         end
-        
+
         def map_kernel(kernel)
           kernel = kernel.each_with_object({}) { |(k, v), h| h[k.downcase.to_sym] = v  }
           kernel.merge! :id => kernel[:kernelid], :name => kernel[:label]
