@@ -10,13 +10,13 @@ module Fog
         model Fog::Compute::Ninefold::Server
 
         def all
-          data = connection.list_virtual_machines
+          data = service.list_virtual_machines
           load(data)
         end
 
         def get(identifier)
           return nil if identifier.nil? || identifier == ""
-          data = connection.list_virtual_machines(:id => identifier)
+          data = service.list_virtual_machines(:id => identifier)
           if data.empty?
             nil
           else
