@@ -7,20 +7,29 @@ module Fog
 
       class Images < Fog::Collection
 
+        attribute :filters
+
         model Fog::Compute::OpenStack::Image
 
         attribute :server
 
-        def all
-          data = connection.list_images_detail.body['images']
-          load(data)
+        def initialize(attributes)
+          self.filters ||= {}
+          super
+        end
+
+        def all(filters = filters)
+          self.filters = filters
+          data = service.list_images_detail(filters).body['images']
+          images = load(data)
           if server
             self.replace(self.select {|image| image.server_id == server.id})
           end
+          images
         end
 
         def get(image_id)
-          data = connection.get_image_details(image_id).body['image']
+          data = service.get_image_details(image_id).body['image']
           new(data)
         rescue Fog::Compute::OpenStack::NotFound
           nil
