@@ -7,10 +7,18 @@ module Fog
 
       class Servers < Fog::Collection
 
+        attribute :filters
+
         model Fog::Compute::OpenStack::Server
 
-        def all
-          data = connection.list_servers_detail.body['servers']
+        def initialize(attributes)
+          self.filters ||= {}
+          super
+        end
+
+        def all(filters = filters)
+          self.filters = filters
+          data = service.list_servers_detail(filters).body['servers']
           load(data)
         end
 
@@ -22,7 +30,7 @@ module Fog
         end
 
         def get(server_id)
-          if server = connection.get_server_details(server_id).body['server']
+          if server = service.get_server_details(server_id).body['server']
             new(server)
           end
         rescue Fog::Compute::OpenStack::NotFound
