@@ -9,7 +9,7 @@ module Fog
             'metadata' => metadata
           }}
           data = server_action(server_id, body)
-          image_id = data.headers["Location"].scan(/.*\/(.*)/).flatten
+          image_id = data.headers["Location"].scan(/.*\/(.*)/).flatten[0]
           get_image_details(image_id)
         end
 
