@@ -3,9 +3,9 @@ module Fog
     class OpenStack
       class Real
 
-        def server_action(server_id, body, expects=202)
+        def server_action(server_id, body, expects=[200,202])
           request(
-            :body     => MultiJson.encode(body),
+            :body     => Fog::JSON.encode(body),
             :expects  => expects,
             :method   => 'POST',
             :path     => "servers/#{server_id}/action.json"
