@@ -6,7 +6,7 @@ module Fog
 
         def update_metadata(collection_name, parent_id, metadata = {})
           request(
-            :body     => MultiJson.encode({ 'metadata' => metadata }),
+            :body     => Fog::JSON.encode({ 'metadata' => metadata }),
             :expects  => 200,
             :method   => 'POST',
             :path     => "#{collection_name}/#{parent_id}/metadata.json"
