@@ -10,12 +10,12 @@ module Fog
         model Fog::Compute::Rackspace::Flavor
 
         def all
-          data = connection.list_flavors_detail.body['flavors']
+          data = service.list_flavors_detail.body['flavors']
           load(data)
         end
 
         def get(flavor_id)
-          data = connection.get_flavor_details(flavor_id).body['flavor']
+          data = service.get_flavor_details(flavor_id).body['flavor']
           new(data)
         rescue Fog::Compute::Rackspace::NotFound
           nil
