@@ -1,6 +1,7 @@
 module Fog
   module Rackspace
     class LoadBalancers
+
       class Real
         def delete_load_balancer(load_balancer_id)
           request(
@@ -10,6 +11,15 @@ module Fog
           )
         end
       end
+
+      class Mock
+        def delete_load_balancer(load_balancer_id)
+          response = Excon::Response.new
+          response.status = 202
+          response.body = ""
+        end
+      end
+
     end
   end
 end
