@@ -14,7 +14,7 @@ module Fog
           end
           #TODO - Do anything if no valid options are passed in?
           request(
-            :body     => MultiJson.encode(data),
+            :body     => Fog::JSON.encode(data),
             :expects  => [200, 202],
             :method   => 'PUT',
             :path     => "loadbalancers/#{load_balancer_id}/nodes/#{node_id}.json"
