@@ -8,20 +8,22 @@ module Fog
         # ==== Parameters
         # * container<~String> - Name of container to look in
         # * object<~String> - Name of object to look for
-        #
+        # @raise [Fog::Storage::Rackspace::NotFound] - HTTP 404
+        # @raise [Fog::Storage::Rackspace::BadRequest] - HTTP 400
+        # @raise [Fog::Storage::Rackspace::InternalServerError] - HTTP 500
+        # @raise [Fog::Storage::Rackspace::ServiceError]
         def get_object(container, object, &block)
-          params = {}
-
-          if block_given?
-            params[:response_block] = Proc.new
-          end
-
-          request(params.merge!({
-            :block    => block,
+          params = {
             :expects  => 200,
             :method   => 'GET',
             :path     => "#{Fog::Rackspace.escape(container)}/#{Fog::Rackspace.escape(object)}"
-          }), false)
+          }
+
+          if block_given?
+            params[:response_block] = block
+          end
+
+          request(params, false)
         end
 
       end
