@@ -5,8 +5,8 @@ module Fog
 
         def create_server(options = {})
           request(
-            :path     => "/storm/server/create",
-            :body     => MultiJson.encode({:params => options})
+            :path     => "/Storm/Server/create",
+            :body     => Fog::JSON.encode({:params => options})
           )
         end
 
