@@ -7,13 +7,13 @@ module Fog
 
       module Mock
         def servers(options = {})
-          Fog::Terremark::Shared::Servers.new(options.merge(:connection => self))
+          Fog::Terremark::Shared::Servers.new(options.merge(:service => self))
         end
       end
 
       module Real
         def servers(options = {})
-          Fog::Terremark::Shared::Servers.new(options.merge(:connection => self))
+          Fog::Terremark::Shared::Servers.new(options.merge(:service => self))
         end
       end
 
@@ -22,24 +22,23 @@ module Fog
         model Fog::Terremark::Shared::Server
 
         def all
-          data = connection.get_vdc(vdc_id).body['ResourceEntities'].select do |entity|
-            entity['type'] == 'application/vnd.vmware.vcloud.vApp+xml'
+          data = []
+          service.get_vdc(vdc_id).body['ResourceEntities'].select do |entity|
+              data << service.servers.get(entity["href"].split('/').last)
           end
-          load(data)
+          data
         end
 
         def get(server_id)
-          if server_id && server = connection.get_vapp(server_id).body
-            new(server)
-          elsif !server_id
+          if server_id
+            new(service.get_vapp(server_id).body)
+          else
             nil
           end
-        rescue Excon::Errors::Forbidden
-          nil
         end
 
         def vdc_id
-          @vdc_id ||= connection.default_vdc_id
+          @vdc_id ||= service.default_vdc_id
         end
 
         private
