@@ -3,7 +3,7 @@ module Fog
     module Terremark
       module Shared
 
-        class GetTasksList < Fog::Parsers::Base
+        class GetTasksList < TerremarkParser
 
           def reset
             @response = { 'Tasks' => [] }
@@ -14,25 +14,12 @@ module Fog
             super
             case name
             when 'Owner', 'Result'
-              data = {}
-              until attributes.empty?
-                data[attributes.shift] = attributes.shift
-              end
+              data = extract_templates(attributes)
               @task[name] = data
             when 'Task'
-              until attributes.empty?
-                @task[attributes.shift] = attributes.shift
-              end
+              @task = extract_templates(attributes)
             when 'TasksList'
-              tasks_list = {}
-              until attributes.empty?
-                if attributes.first.is_a?(Array)
-                  attribute = attributes.shift
-                  tasks_list[attribute.first] = attribute.last
-                else
-                  tasks_list[attributes.shift] = attributes.shift
-                end
-              end
+              tasks_list = extract_templates(attributes)
               @response['href'] = tasks_list['href']
             end
           end
