@@ -3,7 +3,7 @@ module Fog
     module Terremark
       module Shared
 
-        class GetVappTemplate < Fog::Parsers::Base
+        class GetVappTemplate < TerremarkParser
 
           def reset
             @response = { 'Links' => [] }
@@ -13,21 +13,10 @@ module Fog
             super
             case name
             when 'Link'
-              link = {}
-              until attributes.empty?
-                link[attributes.shift] = attributes.shift
-              end            
+              link = extract_attributes(attributes)
               @response['Links'] << link
             when 'VAppTemplate'
-              vapp_template = {}
-              until attributes.empty?
-                if attributes.first.is_a?(Array)
-                  attribute = attributes.shift
-                  vapp_template[attribute.first] = attribute.last
-                else
-                  vapp_template[attributes.shift] = attributes.shift
-                end
-              end
+              vapp_template = extract_attributes(attributes)
               @response['name'] = vapp_template['name']
             end
           end
