@@ -3,7 +3,7 @@ module Fog
     module Terremark
       module Shared
 
-        class Task < Fog::Parsers::Base
+        class Task < TerremarkParser
 
           def reset
             @response = {}
@@ -13,21 +13,10 @@ module Fog
             super
             case name
             when 'Owner', 'Result', 'Link', 'Error'
-              data = {}
-              until attributes.empty?
-                data[attributes.shift] = attributes.shift
-              end
+              data = extract_attributes(attributes)
               @response[name] = data
             when 'Task'
-              task = {}
-              until attributes.empty?
-                if attributes.first.is_a?(Array)
-                  attribute = attributes.shift
-                  task[attribute.first] = attribute.last
-                else
-                  task[attributes.shift] = attributes.shift
-                end
-              end
+              task = extract_attributes(attributes)
               @response.merge!(task.reject {|key,value| !['endTime', 'href', 'startTime', 'status', 'type'].include?(key)})
             end
           end
