@@ -11,18 +11,17 @@ module Fog
         undef_method :create
 
         def all
-          raw_orgs = if connection.version == '1.0'
-            connection.login
+          raw_orgs = if service.version == '1.0'
+            service.login
           else
-            connection.request(connection.basic_request_params("#{connection.base_path_url}/org/"))
+            service.request(service.basic_request_params("#{service.base_path_url}/org/"))
           end
-          data = raw_orgs.body[:Org].select { |org| org[:type] == "application/vnd.vmware.vcloud.org+xml" }
-          data.each { |org| org.delete_if { |key, value| [:rel].include?(key) } }
+          data = raw_orgs.body[:Org]
           load(data)
         end
 
         def get(uri)
-          connection.get_organization(uri)
+          service.get_organization(uri)
         rescue Fog::Errors::NotFound
           nil
         end
