@@ -13,11 +13,11 @@ module Fog
         attribute :href
 
         def all
-          load([connection.get_vdc(self.href).resource_entities].flatten.select { |re| re[:type] == "application/vnd.vmware.vcloud.vApp+xml" })
+          load([service.get_vdc(service.default_vdc_href).resource_entities].flatten.select { |re| re[:type] == "application/vnd.vmware.vcloud.vApp+xml" })
         end
 
         def get(uri)
-          connection.get_vapp(uri)
+          service.get_vapp(uri)
         rescue Fog::Errors::NotFound
           nil
         end
