@@ -6,8 +6,16 @@ module Fog
           # builder = Builder::XmlMarkup.new
           # builder.UndeployVAppParams(:xmlns => 'http://www.vmware.com/vcloud/v1',
           #                            :saveState => save_state) {}
-          builder = "<UndeployVAppParams saveState=\"#{save_state.to_s}\" xmlns=\"http://www.vmware.com/vcloud/v1\"/>"
+          builder = if version =='1.0' 
+                        "<UndeployVAppParams saveState=\"#{save_state.to_s}\" xmlns=\"http://www.vmware.com/vcloud/v1\"/>"
+                    else
+                       <<EOF 
+                        <UndeployVAppParams xmlns="http://www.vmware.com/vcloud/v1.5">
+                        <UndeployPowerAction>shutdown</UndeployPowerAction>
+                        </UndeployVAppParams>
 
+EOF
+                    end
           request(
                   :body     => builder,
                   :expects  => 202,
