@@ -5,7 +5,7 @@ module Fog
         def vm_reconfig_cpus(options = {})
           raise ArgumentError, "cpus is a required parameter" unless options.has_key? 'cpus'
           raise ArgumentError, "instance_uuid is a required parameter" unless options.has_key? 'instance_uuid'
-          hardware_spec={'numCPUs' => options['cpus']}
+          hardware_spec={'numCPUs' => options['cpus'], 'numCoresPerSocket' => options['corespersocket']}
           vm_reconfig_hardware('instance_uuid' => options['instance_uuid'], 'hardware_spec' => hardware_spec )
         end
       end
@@ -14,7 +14,7 @@ module Fog
         def vm_reconfig_cpus(options = {})
           raise ArgumentError, "cpus is a required parameter" unless options.has_key? 'cpus'
           raise ArgumentError, "instance_uuid is a required parameter" unless options.has_key? 'instance_uuid'
-          hardware_spec={'numCPUs' => options['cpus']}
+          hardware_spec={'numCPUs' => options['cpus'], 'numCoresPerSocket' => options['corespersocket']}
           vm_reconfig_hardware('instance_uuid' => options['instance_uuid'], 'hardware_spec' => hardware_spec )
         end
       end
