@@ -3,10 +3,9 @@ module Shindo
 
     def succeeds
       test('succeeds') do
-        instance_eval(&Proc.new)
-        true
+        !!instance_eval(&Proc.new)
       end
     end
 
   end
-end
\ No newline at end of file
+end
